@@ -93,7 +93,7 @@ MODULE = 'authres'
 
 __author__  = 'Julian Mehnle, Scott Kitterman'
 __email__   = 'julian@mehnle.net'
-__version__ = '0.600'
+__version__ = '0.601'
 
 import authres.core
 
@@ -178,8 +178,16 @@ def all_features():
     """
     global _all_features
     if not _all_features:
-        import authres.dkim_b, authres.dkim_adsp, authres.vbr, authres.dmarc
-        _all_features = FeatureContext(authres.dkim_b, authres.dkim_adsp, authres.vbr, authres.dmarc)
+        import authres.dkim_b
+        import authres.dkim_adsp
+        import authres.vbr
+        import authres.dmarc
+        _all_features = FeatureContext(
+            authres.dkim_b,
+            authres.dkim_adsp,
+            authres.vbr,
+            authres.dmarc
+        )
     return _all_features
 
 # Simple API with implicit core-features-only context
